@@ -1,8 +1,17 @@
 import sqlalchemy as sa
 from sqlalchemy import create_engine
+from sqlalchemy.engine import Engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
-from sqlalchemy_i18n import Translatable, configure_translatables
+from sqlalchemy_i18n import Translatable, make_translatable
+
+
+@sa.event.listens_for(Engine, 'before_cursor_execute')
+def count_sql_calls(conn, cursor, statement, parameters, context, executemany):
+    conn.query_count += 1
+
+
+make_translatable(sa.orm.mapper)
 
 
 class TestCase(object):
@@ -10,23 +19,22 @@ class TestCase(object):
         self.engine = create_engine(
             'postgres://postgres@localhost/sqlalchemy_i18n_test'
         )
+        self.connection = self.engine.connect()
+        self.connection.query_count = 0
         self.Model = declarative_base()
 
         self.create_models()
 
-        sa.event.listen(
-            sa.orm.mapper, 'after_configured', configure_translatables
-        )
-
         sa.orm.configure_mappers()
-        self.Model.metadata.create_all(self.engine)
+        self.Model.metadata.create_all(self.connection)
 
-        Session = sessionmaker(bind=self.engine)
+        Session = sessionmaker(bind=self.connection)
         self.session = Session()
 
     def teardown_method(self, method):
         self.session.close_all()
-        self.Model.metadata.drop_all(self.engine)
+        self.Model.metadata.drop_all(self.connection)
+        self.connection.close()
         self.engine.dispose()
 
     def create_models(self):
